@@ -6,7 +6,7 @@ use strict;
 use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(mail);
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 our @HTML_MODULES = qw(HTML::FormatText HTML::TreeBuilder MIME::Lite);
 our @ATTACH_MODULES = qw(File::MMagic MIME::Lite);
 
@@ -116,8 +116,13 @@ sub send {
     } elsif($self->{transport} eq "sendmail") {
         @options = ();
     } elsif($self->{transport} eq "smtp") {
+          # Mail::SMTP likes it that way
+        $ENV{ MAILADDRESS } = $self->{ from };
+
         LOGDIE "No smtp_server set" unless defined $self->{smtp_server};
         @options = ("smtp", Server => $self->{smtp_server});
+        push @options, (Port => $self->{smtp_port}) 
+          if exists $self->{smtp_port};
         $self->{to} = [split /\s*,\s*/, $self->{to}];
     } elsif($self->{transport} eq "mail") {
         return $self->cmd_line_mail();
@@ -498,6 +503,7 @@ deliver the mail. But you can also specify an SMTP server:
       text        => 'test message text',
       transport   => 'smtp',
       smtp_server => 'smtp.foobar.com',
+      smtp_port   => 25, # defaults to 25
     );
 
 Or, if you prefer that Mail::DWIM uses the C<mail> Unix command line
@@ -575,7 +581,7 @@ This will create two attachments, the first one as plain text
 (generated by HTML::Text to the best of its abilities), followed by
 the specified HTML message marked as content-type C<text/html>. 
 Non-HTML mail readers will pick up the first one, and Outlook-using
-marketroids get fancy HTML. Everytext wins.
+marketroids get fancy HTML. Everyone wins.
 
 =head2 Test Mode
 
@@ -613,4 +619,11 @@ modify it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-2007, Mike Schilli <cpan@perlmeister.com>
+    2007, Mike Schilli <cpan@perlmeister.com>
+    
+=head1 LICENSE
+
+Copyright 2007-2014 by Mike Schilli, all rights reserved.
+This program is free software, you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
